@@ -5,9 +5,9 @@ including bill summaries, votes, sponsorships and state legislator
 information.
 """
 __author__ = "Michael Stephens <mstephens@sunlightfoundation.com>"
-__copyright__ = "Copyright (c) 2010 Sunlight Labs"
+__copyright__ = "Copyright (c) 2011 Sunlight Labs"
 __license__ = "BSD"
-__version__ = "0.4.0"
+__version__ = "0.4.2"
 
 from remoteobjects import RemoteObject, fields, ListObject
 import urllib
@@ -94,6 +94,7 @@ class Action(OpenStateObject):
     date = OpenStateDatetime()
     actor = fields.Field()
     action = fields.Field()
+    type = fields.Field()
 
     def __str__(self):
         return '%s: %s' % (self.actor, self.action)
@@ -106,7 +107,7 @@ class Sponsor(OpenStateObject):
     chamber = fields.Field()
 
     def __str__(self):
-        return self.full_name
+        return self.name
 
 
 class SpecificVote(OpenStateObject):
@@ -198,11 +199,12 @@ class Bill(OpenStateObject):
 
 class Role(OpenStateObject):
     state = fields.Field()
-    role = fields.Field()
+    type = fields.Field()
     term = fields.Field()
     chamber = fields.Field()
     district = fields.Field()
     committee = fields.Field()
+    subcommittee = fields.Field()
     start_date = OpenStateDatetime()
     end_date = OpenStateDatetime()
     party = fields.Field()
@@ -221,7 +223,8 @@ class Legislator(OpenStateObject):
     middle_name = fields.Field()
     suffixes = fields.Field()
     votesmart_id = fields.Field()
-    nimsp_candidate_id = fields.Field()
+    nimsp_id = fields.Field()
+    transparencydata_id = fields.Field()
     active = fields.Field()
     chamber = fields.Field()
     district = fields.Field()
@@ -232,6 +235,9 @@ class Legislator(OpenStateObject):
     roles = fields.List(fields.Object(Role))
     sources = fields.List(fields.Object(Source))
 
+    # Deprecated
+    nimsp_candidate_id = fields.Field()
+
     @classmethod
     def get(cls, id):
         """
